kwimage.algo.\_nms\_backend.torch\_nms module
=============================================

.. automodule:: kwimage.algo._nms_backend.torch_nms
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
